NaMaster: nmt_field_flat Struct Reference

NaMaster

- Main Page
- Data Structures
- Files

- Data Structures
- Data Structure Index
- Data Fields

Data Fields
nmt_field_flat Struct Reference

Flat-sky field. More...

`#include <namaster.h>`

## Data Fields
nmt_flatsky_info * | fs
| Structure defining patch geometry. More...
long | npix
| Number of pixels in all maps (also contained in `fs`). More...
int | pure_e
| >0 if E-modes have been purified. More...
int | pure_b
| >0 if B-modes have been purified. More...
flouble * | mask
| Field's mask (an array of `npix` values). More...
fcomplex ** | a_mask
| Fourier transform of the mask. Only computed if E or B are purified. More...
int | spin
| field's spin (>=0). More...
int | nmaps
| Number of maps in the field (2 for spin-2, 1 for spin-0). More...
flouble ** | maps
| Observed field values. When initialized, these maps are already multiplied by the mask, contaminant deprojected and purified if requested. More...
fcomplex ** | alms
| Fourier-transfoms of the maps. More...
int | ntemp
| Number of contaminant templates. More...
flouble *** | temp
| Contaminant template maps (mask-multiplied but NOT purified). More...
fcomplex *** | a_temp
| Fourier-transfomrs of template maps (mask-multiplied AND purified if requested). More...
gsl_matrix * | matrix_M
| Inverse contaminant covariance matrix (see scientific documentation or companion paper). More...
nmt_k_function * | beam
| Function defining a circularly-symmetric beam function. Power spectra will be beam-deconvolved. More...
int | lite
| lightweight field (no maps, temp, a_temp or a_mask) More...
int | mask_only
| this field only contains a mask, and beam. No alms, maps or anything else. More...

## Detailed Description

Flat-sky field.

This structure contains all the information defining a spin-s flat-sky field. This includes field values, masking, purification and contamination.

## Field Documentation

fcomplex** nmt_field_flat::a_mask

Fourier transform of the mask. Only computed if E or B are purified.

fcomplex*** nmt_field_flat::a_temp

Fourier-transfomrs of template maps (mask-multiplied AND purified if requested).

fcomplex** nmt_field_flat::alms

Fourier-transfoms of the maps.

nmt_k_function* nmt_field_flat::beam

Function defining a circularly-symmetric beam function. Power spectra will be beam-deconvolved.

nmt_flatsky_info* nmt_field_flat::fs

Structure defining patch geometry.

int nmt_field_flat::lite

lightweight field (no maps, temp, a_temp or a_mask)

flouble** nmt_field_flat::maps

Observed field values. When initialized, these maps are already multiplied by the mask, contaminant deprojected and purified if requested.

flouble* nmt_field_flat::mask

Field's mask (an array of `npix` values).

int nmt_field_flat::mask_only

this field only contains a mask, and beam. No alms, maps or anything else.

gsl_matrix* nmt_field_flat::matrix_M

Inverse contaminant covariance matrix (see scientific documentation or companion paper).

int nmt_field_flat::nmaps

Number of maps in the field (2 for spin-2, 1 for spin-0).

long nmt_field_flat::npix

Number of pixels in all maps (also contained in `fs`).

int nmt_field_flat::ntemp

Number of contaminant templates.

int nmt_field_flat::pure_b

>0 if B-modes have been purified.

int nmt_field_flat::pure_e

>0 if E-modes have been purified.

int nmt_field_flat::spin

field's spin (>=0).

flouble*** nmt_field_flat::temp

Contaminant template maps (mask-multiplied but NOT purified).

The documentation for this struct was generated from the following file:

- namaster.h